clear
log using BDEajps.marinov.log, replace

****************************************************************************
****************************************************************************
* File to replicate Table 2, Column 3 of Marinov (2005 AJPS) and simulate  *
* predicted effects of sanctions on Pr(Leader Survives) as the sanctioning *
* method varies.                                                           *
****************************************************************************
* Written by: Jacqueline Demeritt					   *
* Created on: 20 July 2008						   *
* Last edited on: 29 June 2009					   	   *
****************************************************************************
****************************************************************************

set mem 500m
set matsize 800
set more off
set seed 000011

* This is the replication dataset and model as reported in Table 2, Column 3
* of the published paper:

use "/Users/jacqueline/Desktop/research/Berry-Esarey-Demeritt/AJPS_R&R_stuff/marinov_replication/marinov/marinov_ldpaper.dta"
xtlogit fail sanctionsl1 xdemocl1 xlngdptl1 xcost xinstl1 forcel1 lngdppc democl1 democlnt mixedl1 mixedlnt age ot3 _s*, fe nolog

* This is the same model, run using the new (larger) dataset sent directly from Marinov:
clear
use "/Users/jacqueline/Desktop/research/Berry-Esarey-Demeritt/AJPS_R&R_stuff/marinov_replication/marinov/ldpaper0304.dta"
xtlogit fail sanctionsl1 xdemocl1 xlngdptl1 xcost xinstl1 forcel1 lngdppc democl1 democlnt mixedl1 mixedlnt age ot3 _s*, fe nolog

***************************************************************************
* Note that the two models above are identical. Now, I proceed using only *
* the new, larger dataset provided by Marinov.                            *
***************************************************************************

* recreate interaction terms and see if newly-created XZ terms match the terms in the published model:

***********************
* Sanctions*Democracy *
***********************
gen sancxdemoc=sanctionsl1*democl1
corr sancxdemoc xdemocl1
gen checkdemoc=sancxdemoc-xdemocl1
* If the interaction term is accurate, the variable 'checkdemoc' should be zero for all observations:
sum checkdemoc
drop sancxdemoc checkdemoc

********************
* Sanctions*Wealth *
********************

* Marinov uses GDPpc as the additive term and claims to use gdpM as the term
* that interacts with sanctions.  It turns out that he uses a the natural log
* of a one-period lag of gdpM (which is called gdpMll1):

gen sancxwealth=sanctionsl1*gdpMll1
corr sancxwealth xlngdptl1
gen checkwealth=sancxwealth-xlngdptl1
sum checkwealth
drop sancxwealth checkwealth

* Now, since the specification has changed, let's take another look
* at the model, correctly specified.  Note that 'lngdppc' is now 'gdpMll1',
* which is the proper constitutent term for xlngdptl1:
xtlogit fail sanctionsl1 xdemocl1 xlngdptl1 xcost xinstl1 forcel1 gdpMll1 democl1 democlnt mixedl1 mixedlnt age ot3 _s*, fe nolog

* Record the sample included in this model to ensure valid inferences below:
gen sample=1 if e(sample)
replace sample=0 if ~e(sample)
tab sample

*******************************************************************************
* Note that this correction does not meaningfully change the results in terms *
* of sign, size or significance of the MLEs.                                  *
*******************************************************************************

******************
* Sanctions*Cost *
******************

* Marinov does not include cost as a constituent term in his published model,
* and claims that he multiplied sanctionsl1 by the variable 'ct2' to create
* the relevant interaction term. It turns out that he uses a one-period
* lag of ct2 (which was not included as a variable in either dataset Marinov
* provided).

gen sancxcost=sanctionsl1*ct2[_n-1]
corr sancxcost xcost
gen checkcost=sancxcost-xcost
sum checkcost
drop sancxcost checkcost

**************************
* Sanctions*Institutions *
**************************

* Again, Marinov does not include institutions as a constituent term in 
* the published model. He claims that he multiplied sanctionsl1 by the
* variable 'hseisum' to create the relevant interaction term, but 'hseisum'
* is a string variable in the STATA dataset. 'hseinst' is the destrung 
* version of hseisum, but multiplying it by sanctionsl1 does not produce 
* xinstl1.  Neither does multiplying its lag, or multiplying its log, or 
* multiplying its logged lag. 
*
* After consulting with Marinov, we now know that he, "by mistake, created
* a dummy equal to 1 for all cases where hseisum was non-missing, and 
* proceeded to use that as the destrung version of hseisum. This is wrong 
* because hseisum is sometimes "0", meaning no institution levying, and so 
* my interaction term overcodes the true incidence of institutional support."
*
* Unfortunately, this new information does provide much help.  What Marinov
* intended to do was (1) destring the institutions variable, (2) lag it, and 
* (3) multiply it with sanctionsl1.
*
* What he claims to have done, by mistake, is (1) destring the institutions 
* variable, (2) generate a dummy variable which equals 1 if the institutions 
* variable is non-missing and 0 if it is missing, and (3) multiply that dummy 
* variable with sanctionsl1. So let's try that (hseinst is the destrung 
* institutions variable):

gen hseinstb=0 if hseinst==.
replace hseinstb=1 if hseinst~=.

* If this successfully recreated the constitution term, we should be able to 
* interact it with sanctionsl1 to recreate the interaction term `xinstl1' 
* that Marinov uses in his analysis:

gen sancxinst=hseinstb*sanctionsl1
corr sancxinst xinstl1

* Clearly, this cannot be right. So perhaps Marinov lagged the binary 
* variable before interacting it?

drop sancxinst
gen hseinstbl1=hseinstb[_n-1]
gen sancxinst=hseinstbl1*sanctionsl1
corr sancxinst xinstl1

* Nope.  Perhaps he interacted the binary variable with a non-lagged 
* version of sanctions?

drop sancxinst
gen sancxinst=sanctions*hseinstb[_n-1]
corr sancxinst xinstl1

* Nope.  At this point, I'm fairly confident that what Marinov thinks he has 
* done is not, in fact, what he has done.  And, I am still unable to create 
* an interaction of sanctions and institutions that correlates perfectly with 
* Marinov's 'xinstl1'.  But I have been able to create a variable that correlates 
* very highly (r=.98) with `xinstl1' by (1) destringing hseisum, (2) creating a 
* dummy variable that equals 1 if Marinov's institutions variable is non-missing 
* and is greater than 0, and equals 0 if Marinov's institutions variable is either 
* equal to 0 or missing, (3) lagging that binary variable, and (4) interacting it 
* with sanctionsl1:

drop sancxinst hseinstb hseinstbl1
gen hseinstb=0 if hseinst==0
replace hseinstb=1 if hseinst>0
replace hseinstb=0 if hseinst==.
gen hseinstbl1=hseinstb[_n-1]
gen sancxinst=sanctionsl1*hseinstb[_n-1]
corr sancxinst xinstl1

* When I replace Marinov's xinstl1 variable with this newly-created `sancxinst' 
* variable, the MLEs are remarkably similar in terms of sign, magnitude and 
* statistical significance as those estimated using the original, un-replicable 
* `xinstl1'. The only potentially problematic change is in the magnitude of
* the coefficient MLE on the sanctions*institutions interaction that has been at issue,
* which drops from .4515 to .2830 when the newly-created variable is included in place
* of Marinov's `xinstl1':

xtlogit fail sanctionsl1 xdemocl1 xlngdptl1 xcost xinstl1 forcel1 lngdppc democl1 democlnt mixedl1 mixedlnt age ot3 _s*, fe nolog
xtlogit fail sanctionsl1 xdemocl1 xlngdptl1 xcost sancxinst forcel1 lngdppc democl1 democlnt mixedl1 mixedlnt age ot3 _s*, fe nolog

* So, now that we've got the interaction terms mostly figured out, let's head 
* to an analysis of various quantities of interest.

**************************************************************************
**************************************************************************
* Conduct CLARIFY analysis to compute a min-max 2nd difference, treating *
* sanctions as the variable whose effects are modified and democracy as  *
* the modifying variable.				 		 *
**************************************************************************
**************************************************************************

* Sanctions*Democracy
* NOTE: Both variables are binary.  Therefore, I compute the min-max second
* difference rather than discrete differences in marginal effects.
*
* As Marinov notes, CLARIFY does not support xtlogit.  Following the author,
* I rerun the model as an ordinary logit, including country dummies to
* proxy the original fixed effects specification.  Also like the author, I
* find that point estimates and standard errors are remarkably similar across
* the two specifications.  For more details, see Marinov's footnote 26 (p573).

* The first model below is the model reported in the published paper, with the GDP term corrected.
* The second model is the ordinary logit with country-level fixed effects, and the command
* also generates the country codes needed to implement the third model, which is another ordinary 
* logit with country-level FEs (identical to the second model), but which calls the CLARIFY
* program into use.  To see that these models are remarkably similar, simply remove the 
* stars from the front of the first line of code.

*xtlogit fail sanctionsl1 xdemocl1 xlngdptl1 xcost xinstl1 forcel1 gdpMll1 democl1 democlnt mixedl1 mixedlnt age ot3 _s*, fe nolog
xi: logit fail sanctionsl1 xdemocl1 xlngdptl1 xcost xinstl1 forcel1 gdpMll1 democl1 democlnt mixedl1 mixedlnt age ot3 _s* i.ccode, nolog
gen ct2l1=ct2[_n-1]
sum sanctionsl1 gdpMll1 ct2l1 
estsimp logit fail sanctionsl1 xdemocl1 xlngdptl1 xcost xinstl1 forcel1 gdpMll1 democl1 democlnt mixedl1 mixedlnt age ot3 _s* _Iccode_20 _Iccode_40 _Iccode_41 _Iccode_42 _Iccode_51 _Iccode_52 _Iccode_70 _Iccode_90 _Iccode_91 _Iccode_92 _Iccode_93 _Iccode_94 _Iccode_95 _Iccode_100 _Iccode_101 _Iccode_110 _Iccode_130 _Iccode_135 _Iccode_140 _Iccode_145 _Iccode_150 _Iccode_155 _Iccode_160 _Iccode_165 _Iccode_200 _Iccode_205 _Iccode_210 _Iccode_211 _Iccode_220 _Iccode_230 _Iccode_235 _Iccode_260 _Iccode_265 _Iccode_290 _Iccode_305 _Iccode_310 _Iccode_315 _Iccode_316 _Iccode_317 _Iccode_325 _Iccode_339 _Iccode_343 _Iccode_345 _Iccode_350 _Iccode_352 _Iccode_355 _Iccode_359 _Iccode_360 _Iccode_365 _Iccode_368 _Iccode_375 _Iccode_380 _Iccode_385 _Iccode_390 _Iccode_395 _Iccode_404 _Iccode_411 _Iccode_420 _Iccode_432 _Iccode_433 _Iccode_434 _Iccode_435 _Iccode_436 _Iccode_437 _Iccode_438 _Iccode_439 _Iccode_450 _Iccode_451 _Iccode_452 _Iccode_461 _Iccode_471 _Iccode_475 _Iccode_481 _Iccode_482 _Iccode_483 _Iccode_484 _Iccode_490 _Iccode_500 _Iccode_510 _Iccode_516 _Iccode_517 _Iccode_520 _Iccode_522 _Iccode_560 _Iccode_570 _Iccode_571 _Iccode_580 _Iccode_581 _Iccode_590 _Iccode_615 _Iccode_616 _Iccode_620 _Iccode_625 _Iccode_630 _Iccode_640 _Iccode_645 _Iccode_651 _Iccode_652 _Iccode_660 _Iccode_666 _Iccode_670 _Iccode_678 _Iccode_680 _Iccode_690 _Iccode_694 _Iccode_700 _Iccode_710 _Iccode_712 _Iccode_740 _Iccode_750 _Iccode_760 _Iccode_770 _Iccode_771 _Iccode_775 _Iccode_780 _Iccode_800 _Iccode_811 _Iccode_812 _Iccode_816 _Iccode_820 _Iccode_830 _Iccode_840 _Iccode_850 _Iccode_900 _Iccode_910 _Iccode_920 _Iccode_950 if sample==1

* set additive terms at their means, and set interactive terms at 
* the product of their means rather than the mean of their products. 

setx mean
setx xlngdptl1 .1275265*22.80711  xcost .1275265*2.54725 xinstl1 .1275265*.0322049

*Pr(survive) when sanctions=0 and democracy=0
setx sanctionsl1 0 democl1 0 xdemocl1 0
simqi, prval(1) genpr(pr00) 

*Pr(survive) when sanctions=0 and democracy=1
setx sanctionsl1 0 democl1 1 xdemocl1 0
simqi, prval(1) genpr(pr01) 

*Pr(survive) when sanctions=1 and democracy=0
setx sanctionsl1 1 democl1 0 xdemocl1 0
simqi, prval(1) genpr(pr10) 

*Pr(survive) when sanctions=1 and democracy=1
setx sanctionsl1 1 democl1 1 xdemocl1 1
simqi, prval(1) genpr(pr11) 

*First difference in Pr(survive) when democracy=0 and sanctions vary from 0 to 1
gen sldemoc0 = pr10 - pr00

*First difference in Pr(survive) when democracy=1 and sanctions vary from 0 to 1
gen sldemoc1 = pr11 - pr01

*************************************************
*************************************************
* Below is the second difference reported 	*
* in the text of our AJPS paper:		*
*************************************************
*************************************************

*Min-max second difference: Effect of democracy on the effect of sanctions on Pr(survive)
gen dsl_democcontext = sldemoc1 - sldemoc0
sumqi sldemoc0 sldemoc1 dsl_democcontext

log close
